@@ -1,7 +1,8 @@
 from functions import Virus
 
 def main(time = 10):
-    Virus.start(time)
+    starter = Virus
+    starter.open_website(time, time)
 
 if __name__ == '__main__':
-    main()
+    main(1)
