@@ -20,12 +20,12 @@ sites = [
 
 
 class Virus:
-    def __open_website(duration):
+    def open_website(self, duration):
         t = 0
-        while t <= duration_:
+        while t <= duration:
             webbrowser.open(random.choice(sites))
             time.sleep(1)
             t += 1
 
-    def start(duration = 10): #Default site type is 'sfw' and duration is 10 minutes
-        __open_website(duration*60)
+    def start(self, duration = 10): #Default site type is 'sfw' and duration is 10 minutes
+        open_website(duration*60)
